@@ -43,7 +43,9 @@ def pcam_patches(
             The dataset that loads the pcam patches. You can use this
             as normal pytorch dataset. If you call it, the data will
             be returned as dictionary with structure:
-            dict['images': torch.Tensor, 'labels': torch.Tensor].
+            dict['images': torch.Tensor, 'feature': torch.Tensor].
+            The feature 0 stands for Normal-Tissue, the label 1 stands for
+            Metastase-Tissue.
     """
     root = os.path.expanduser(root)
 
